@@ -44,14 +44,14 @@
 #'
 #' @source
 #' \enumerate{
-#'    \item r - How can I check if a file is empty? - Stack Overflow answered by Konrad Rudolph and edited by Geekuna Matata on Apr 23 2014. See \url{http://stackoverflow.com/questions/23254002/how-can-i-check-if-a-file-is-empty}.
-#'    \item r - Better error message for stopifnot? - Stack Overflow answered by Andrie on Dec 1 2011. See \url{http://stackoverflow.com/questions/8343509/better-error-message-for-stopifnot}.
-#'    \item RDocumentation: TclInterface {tcltk}. See \url{http://www.rdocumentation.org/packages/tcltk/versions/3.3.1/topics/TclInterface}.
-#'    \item James Wettenhall & Philippe Grosjean, File Open/Save dialogs in R tcltk, December 01, 2015. See \url{http://www.sciviews.org/recipes/tcltk/TclTk-file-open-save-dialogs/}.
-#'    \item Replacing nth line in a text file in R - Stack Overflow answered by Spacedman on Aug 1 2012. See \url{http://stackoverflow.com/questions/11756353/replacing-nth-line-in-a-text-file-in-r}.
-#'    \item r - read csv files and perform function, then bind together - Stack Overflow answered by bjoseph on Jan 8 2015. See \url{http://stackoverflow.com/questions/27846715/read-csv-files-and-perform-function-then-bind-together}.
-#'    \item multiple output filenames in R - Stack Overflow asked and edited by Gabelins on Feb 1 2013. See \url{http://stackoverflow.com/questions/14651594/multiple-output-filenames-in-r}.
-#'    \item r - Regex return file name, remove path and file extension - Stack Overflow answered and edited by Ananda Mahto on Feb 25 20134. See \url{http://stackoverflow.com/questions/15073753/regex-return-file-name-remove-path-and-file-extension/15073919}.
+#'    \item r - How can I check if a file is empty? - Stack Overflow answered by Konrad Rudolph and edited by Geekuna Matata on Apr 23 2014. See \url{https://stackoverflow.com/questions/23254002/how-can-i-check-if-a-file-is-empty}.
+#'    \item r - Better error message for stopifnot? - Stack Overflow answered by Andrie on Dec 1 2011. See \url{https://stackoverflow.com/questions/8343509/better-error-message-for-stopifnot}.
+#'    \item RDocumentation: TclInterface {tcltk}. See \url{https://www.rdocumentation.org/packages/tcltk/versions/3.3.1}.
+#'    \item James Wettenhall & Philippe Grosjean, File Open/Save dialogs in R tcltk, December 01, 2015. See \url{https://web.archive.org/web/20160521051207/http://www.sciviews.org/recipes/tcltk/TclTk-file-open-save-dialogs/}. Retrieved thanks to the Internet Archive: Wayback Machine
+#'    \item Replacing nth line in a text file in R - Stack Overflow answered by Spacedman on Aug 1 2012. See \url{https://stackoverflow.com/questions/11756353/replacing-nth-line-in-a-text-file-in-r}.
+#'    \item r - read csv files and perform function, then bind together - Stack Overflow answered by bjoseph on Jan 8 2015. See \url{https://stackoverflow.com/questions/27846715/read-csv-files-and-perform-function-then-bind-together}.
+#'    \item multiple output filenames in R - Stack Overflow asked and edited by Gabelins on Feb 1 2013. See \url{https://stackoverflow.com/questions/14651594/multiple-output-filenames-in-r}.
+#'    \item r - Regex return file name, remove path and file extension - Stack Overflow answered and edited by Ananda Mahto on Feb 25 20134. See \url{https://stackoverflow.com/questions/15073753/regex-return-file-name-remove-path-and-file-extension/15073919}.
 #' }
 #'
 #' @encoding UTF-8
@@ -64,7 +64,7 @@
 #' @examples
 #' \dontrun{
 #' # Examples to change (a) .psf file(s) interactively and non-interactively
-#' library(ie2misc)
+#' library("ie2misc")
 #' psfFileChange() # default where interactive = TRUE
 #' # Follow the file dialog instructions
 #'
@@ -99,10 +99,12 @@
 #' }
 #'
 #' @import stringi
-#' @import qdap
+#' @import mgsub
 #' @import tcltk
 #' @import gWidgets2
 #' @import gWidgets2tcltk
+#' @import data.table
+#' @import tools
 #'
 #'
 #' @name psfFileChange
@@ -147,8 +149,8 @@ if (file.info(file)$size == 0) {
 
 rddatatmp <- readLines(file)
 # read in file as a string of characters line by line and save as rddatatmp
-rddatatmp <- multigsub(pattern, replacement, rddatatmp, fixed = FALSE)
-# multiple substitution replacement using qdap's multigsub function
+rddatatmp <- mgsub(rddatatmp, pattern, replacement, fixed = FALSE)
+# multiple substitution replacement using mgsub's mgsub function
 rddatatmplocate1 <- stri_detect_fixed(rddatatmp, "SkewSE")
 # search for the pattern using the stringi's stri_detect_fixed function
 
@@ -200,8 +202,8 @@ if (file.info(file[i])$size == 0) {
 # read in file as a string of characters line by line and save as rddatatmp
   rddatatmp <- assign(file[i], get(file[i]))
 # Source 6 ends
-  rddatatmp <- multigsub(pattern, replacement, rddatatmp, fixed = FALSE)
-# multiple substitution replacement using qdap's multigsub function
+  rddatatmp <- mgsub(rddatatmp, pattern, replacement, fixed = FALSE)
+# multiple substitution replacement using mgsub's mgsub function
   rddatatmplocate1 <- stri_detect_fixed(rddatatmp, "SkewSE")
 # search for the pattern using the stringi's stri_detect_fixed function
 
@@ -236,8 +238,8 @@ for (i in 1:length(file)) {
 # read in file as a string of characters line by line and save as rddatatmp
   rddatatmp <- assign(file[i], get(file[i]))
 # Source 6 ends
-  rddatatmp <- multigsub(pattern, replacement, rddatatmp, fixed = FALSE)
-# multiple substitution replacement using qdap's multigsub function
+  rddatatmp <- mgsub(rddatatmp, pattern, replacement, fixed = FALSE)
+# multiple substitution replacement using mgsub's mgsub function
   rddatatmplocate1 <- stri_detect_fixed(rddatatmp, "SkewSE")
 # search for the pattern using the stringi's stri_detect_fixed function
 
@@ -316,8 +318,8 @@ if (file.info(file[i])$size == 0) {
   rddatatmp <- assign(file[i], get(file[i]))
 # Source 6 ends
 
-  rddatatmp <- multigsub(pattern, replacement, rddatatmp, fixed = FALSE)
-# multiple substitution replacement using qdap's multigsub function
+  rddatatmp <- mgsub(rddatatmp, pattern, replacement, fixed = FALSE)
+# multiple substitution replacement using mgsub's mgsub function
   rddatatmplocate1 <- stri_detect_fixed(rddatatmp, "SkewSE")
 # search for the pattern using the stringi's stri_detect_fixed function
 
